#[non_exhaustive]pub struct EncoderParams {
pub use_predictor_transform: bool,
pub use_lossy: bool,
pub lossy_quality: u8,
}Expand description
Allows fine-tuning some encoder parameters.
Pass to [WebPEncoder::set_params()].
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.use_predictor_transform: boolUse a predictor transform. Enabled by default.
use_lossy: boolUse the lossy encoding to encode the image using the VP8 compression format.
lossy_quality: u8A quality value for the lossy encoding that must be between 0 and 100. Defaults to 95.